@@ -24,12 +24,13 @@
 
 /* Data types */
 
-typedef gboolean (*UpdateThreadCallback)(ViewAddingSession* session, JsonObject* feed, Http* http, time_t delta, gpointer user_data);
+typedef gboolean (*UpdateThreadCallback)(ViewAddingSession* session, JsonObject* feed, MicrofeedHttp* http, time_t delta, gpointer user_data);
+typedef void (*InitializeHttpCallback)(MicrofeedHttp* http, gpointer user_data);
 
 /* Static functions */
 
 GList* backend_append_links_to_selections(GList* selections, gchar* text, GCallback callback);
-void backend_start_update(View* view, gchar* url, gchar* userpass, ViewItemSource* item_source, gboolean keep_old_items, UpdateThreadCallback update_thread_callback, gpointer user_data);
+void backend_start_update(View* view, gchar* url, gchar* userpass, ViewItemSource* item_source, gboolean keep_old_items, UpdateThreadCallback update_thread_callback, InitializeHttpCallback initialize_http_callback, gpointer user_data);
 void backend_update_marked_items_view(View* view);
 
 #endif
