@@ -1,7 +1,7 @@
 /*****************************************************************************
  *** Mauku - Jaiku client for Maemo devices 
  ***
- *** Copyright (c) 2007 Henrik Hedberg <hhedberg@innologies.fi>
+ *** Copyright (c) 2007 - 2009 Henrik Hedberg <hhedberg@innologies.fi>
  ***
  *** Licensed under the Apache License, Version 2.0 (the "License");
  *** you may not use this file except in compliance with the License.
@@ -22,6 +22,9 @@
 #ifndef _XOPEN_SOURCE
 #define _XOPEN_SOURCE /* strptime/time.h: glibc2 needs this */
 #endif
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE /* memrchr */
+#endif
 
 #include <glib.h>
 #include <gtk/gtk.h>
@@ -55,27 +58,24 @@ typedef struct {
 } JaikuData;
 
 static gint compare_item_nicks(gconstpointer a, gconstpointer b);
-static gchar* do_login();
-static void* login_thread(void* args);
 static GString* get_comment_count(JsonObject* comments);
-static gboolean get_posting_data(Http* http, gchar* url, gchar** nonce, gchar** location);
-static gchar* handle_json_item(JsonObject* json, ViewAddingSession* session, Http* http, gboolean skip_comment, gchar* referred_unique_id, time_t delta);
+static gchar* handle_json_item(JsonObject* json, ViewAddingSession* session, MicrofeedHttp* http, gboolean skip_comment, gchar* referred_unique_id, time_t delta);
 static void on_contact_clicked_callback(View* view, ViewItem* item, gboolean was_avatar);
 static void on_item_destroy_callback(ViewItem* item);
 static void on_jaiku_clicked_callback(View* view, ViewItem* item, gboolean was_avatar);
 static void on_channel_menu_item_activate(GtkMenuItem* menu_item, gpointer user_data);
 static void on_jaiku_menu_item_activate(GtkMenuItem* menu_item, gpointer user_data);
 static void on_link_menu_item_activate(GtkMenuItem* menu_item, gpointer user_data);
-static ViewItem* parse_json_item(JsonObject* json, gchar* unique_id, Http* http, gchar* referred_unique_id, time_t delta);
-static void parse_json_item_comment(JsonObject* json, ViewItem* item, Http* http, GString* string,  GString* speech);
-static void parse_json_item_jaiku(JsonObject* json, ViewItem* item, Http* http, GString* string, GString* speech);
-static gboolean update_contacts_view_callback(ViewAddingSession* session, JsonObject* feed, Http* http, time_t delta, gpointer user_data);
+static ViewItem* parse_json_item(JsonObject* json, gchar* unique_id, MicrofeedHttp* http, gchar* referred_unique_id, time_t delta);
+static void parse_json_item_comment(JsonObject* json, ViewItem* item, MicrofeedHttp* http, GString* string,  GString* speech);
+static void parse_json_item_jaiku(JsonObject* json, ViewItem* item, MicrofeedHttp* http, GString* string, GString* speech);
+static gboolean update_contacts_view_callback(ViewAddingSession* session, JsonObject* feed, MicrofeedHttp* http, time_t delta, gpointer user_data);
 static void* update_marked_items_thread(void* data);
-static gboolean update_overview_callback(ViewAddingSession* session, JsonObject* feed, Http* http, time_t delta, gpointer user_data);
+static gboolean update_overview_callback(ViewAddingSession* session, JsonObject* feed, MicrofeedHttp* http, time_t delta, gpointer user_data);
 static void update_thread_view(View* view);
-static gboolean update_thread_view_callback(ViewAddingSession* session, JsonObject* feed, Http* http, time_t delta, gpointer user_data);
+static gboolean update_thread_view_callback(ViewAddingSession* session, JsonObject* feed, MicrofeedHttp* http, time_t delta, gpointer user_data);
 static void update_user_view(View* view);
-static gboolean update_user_view_callback(ViewAddingSession* session, JsonObject* feed, Http* http, time_t delta, gpointer user_data);
+static gboolean update_user_view_callback(ViewAddingSession* session, JsonObject* feed, MicrofeedHttp* http, time_t delta, gpointer user_data);
 
 ViewItemSource jaiku_item_source = {
 	"jaiku",
@@ -106,100 +106,122 @@ static ViewItemClass contact_item_class = {
 	on_contact_clicked_callback,  NULL
 };
 
-gboolean jaiku_handle_marked_item(ViewAddingSession* session, Http* http, gchar* unique_id, gchar* url) {
+static int oauth_authorize_callback(MicrofeedHttp* http, const char* url, void* user_data) {
+	osso_rpc_t retval;
+	GtkWidget* note;
+	
+	gdk_threads_enter();
+	printf("=> %s\n", url);
+	osso_rpc_run(osso_context, "com.nokia.osso_browser", "/com/nokia/osso_browser", "com.nokia.osso_browser",
+	             "open_new_window", &retval,  DBUS_TYPE_STRING, url, DBUS_TYPE_INVALID);
+
+	note = hildon_note_new_information(GTK_WINDOW(user_data), "Use a web browser to authorize Mauku to access your Jaiku account and click the button below after that.");
+	hildon_note_set_button_text(HILDON_NOTE(note), "Authorization done");
+	gtk_dialog_run(GTK_DIALOG(note));
+	gtk_widget_destroy(note);
+	gdk_threads_leave();
+	
+	return 1;
+}
+
+static void oauth_access_callback(MicrofeedHttp* http, const char* access_token, const char* access_token_secret, void* user_data) {
+	gdk_threads_enter();
+	gconf_client_set_string(gconf, MAUKU_GCONF_KEY_JAIKU_ACCESS_TOKEN, (access_token ? access_token : ""), NULL);
+	gconf_client_set_string(gconf, MAUKU_GCONF_KEY_JAIKU_ACCESS_TOKEN_SECRET, (access_token_secret ? access_token_secret : ""), NULL);
+	gdk_threads_leave();
+}
+
+static void initialize_http(MicrofeedHttp* http, void* user_data) {
+	gchar* access_token = NULL;
+	gchar* access_token_secret = NULL;
+
+	microfeed_http_set_oauth_authentication(http, "http://www.jaiku.com/api/request_token", "http://www.jaiku.com/api/authorize?perms=delete", "http://www.jaiku.com/api/access_token", "cf55e6341c5e4c27b8f0fff01cc8a84c", "03cd1ccb890645ffae0b60202e584c58", oauth_authorize_callback, oauth_access_callback, user_data);
+	if ((access_token = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_ACCESS_TOKEN, NULL)) && *access_token &&
+            (access_token_secret = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_ACCESS_TOKEN_SECRET, NULL)) && *access_token_secret) {
+		microfeed_http_set_oauth_access_token(http, access_token, access_token_secret);
+	}
+	g_free(access_token);
+	g_free(access_token_secret);
+}
+
+static void initialize_http_callback(MicrofeedHttp* http, void* user_data) {
+
+	gdk_threads_enter();
+	initialize_http(http, user_data);
+	gdk_threads_leave();
+}
+
+gboolean jaiku_handle_marked_item(ViewAddingSession* session, MicrofeedHttp* http, gchar* unique_id, gchar* url) {
 	gboolean retvalue = FALSE;
-	gchar* name = NULL;
-	gchar* key = NULL;
-	gchar* real_url = NULL;
+	gchar* real_url;
 	JsonObject* feed;
 	time_t delta;
 	
-	gdk_threads_enter();
-	if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL)) && *name &&
-	    (key = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_KEY, NULL)) && *key) {
-		real_url = g_strconcat(url, "/json?user=", name, "&personal_key=", key, NULL);
-	}
-	gdk_threads_leave();
-	
-	if (real_url) {
-		if ((feed = http_get_json_object(http, real_url))) {
-			if (http_get_server_time(http)) {
-				delta = http_get_server_time(http) - http_get_reply_start_time(http);
-			} else {
-				delta = 0;
-			}
-			if (handle_json_item(feed, session, http, FALSE, NULL, delta)) {
-				retvalue = TRUE;
-			}
-			json_object_put(feed);
+	real_url = g_strconcat(url, "/json", NULL);
+	initialize_http_callback(http, view_get_window(view_adding_session_get_view(session)));
+	if ((feed = microfeed_http_get_json_object(http, real_url))) {
+		if (microfeed_http_get_server_time(http)) {
+			delta = microfeed_http_get_server_time(http) - microfeed_http_get_reply_start_time(http);
+		} else {
+			delta = 0;
 		}
-		g_free(real_url);
-	} else {
-		retvalue = TRUE;
+		microfeed_http_unset_oauth_authentication(http);
+		if (handle_json_item(feed, session, http, FALSE, NULL, delta)) {
+			retvalue = TRUE;
+		}
+		json_object_put(feed);
 	}
+	g_free(real_url);
 
 	return retvalue;
 }
 
-void jaiku_start_login() {
-	gchar* key = NULL;
-	gchar* name = NULL;
-	gchar* password = NULL;
-
-	if ((!(key = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_KEY, NULL)) || !*key)) {
-		if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL)) && *name &&
-		    (password = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_PASSWORD, NULL)) && *password) {
-			if (http_is_connected()) {
-				if (g_thread_create(login_thread, view_get_topmost_view(), FALSE, NULL) == NULL) {
-					/* TODO: Failed... */
-				}
-			}
-		}
-	}
-	g_free(key);
-	g_free(name);
-	g_free(password);
-}
-
 gboolean jaiku_send_comment(const gchar* url, const gchar* text) {
 	gboolean retvalue = FALSE;
 	gchar* name = NULL;
-	gchar* key = NULL;
-	Http* http;
-	gchar* real_url;
+	MicrofeedHttp* http;
+	gchar* uid;
+	gchar* owner;
 	GString* string;
 	gchar* nonce;
 	gchar* location;
 	gchar* s;
 	size_t len;
 
-	if (http_make_connected() && (http = http_new())) {
-		if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL)) && *name &&
-		    (key = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_KEY, NULL)) && *key) {
-			real_url = g_strconcat(url, "?user=", name, "&personal_key=", key, NULL);
-			if (get_posting_data(http, real_url, &nonce, &location) && nonce) {
-				string = g_string_new("user=");
-				g_string_append(string, gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL));
-				g_string_append(string, "&personal_key=");
-				g_string_append(string, gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_KEY, NULL));
-				g_string_append(string, "&_nonce=");
-				g_string_append(string, nonce);
-				g_string_append(string, "&comment=");
-				s = http_url_encode(http, text);
-				g_string_append(string, s);
-				http_free(http, s);
-
-				if (http_post_data(http, url, &len, string->str)) {
-					retvalue = TRUE;
-				}			
-
-				g_string_free(string, TRUE);
-				g_free(nonce);
-				g_free(location);
-			}
-			g_free(real_url);
+	if (!strncmp(url, "http://www.jaiku.com/channel/", 29) && (s = strchr(url + 29, '/'))) {
+		s = strndup(url + 29, s - url - 29);
+		owner = g_strconcat("%23", s, NULL);
+		free(s);
+	} else if ((s = strchr(url, '.')) && s - url > 7) {
+		owner = strndup(url + 7, s - url - 7);
+	}
+	if (owner && (uid = strrchr(url, '/')) && network_make_connected() && (http = microfeed_http_new())) {
+		uid++;
+		initialize_http(http, NULL);
+		if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL)) && *name) {
+			string = g_string_new("method=entry_add_comment&nick=");
+			g_string_append(string, name);
+			g_string_append(string, "%40jaiku.com&stream=stream%2F");
+			g_string_append(string, (*owner == '%' ? name : owner)); /* Should this be name always? If it is, Jaiku constructs wrong link to original entry. */
+			g_string_append(string, "%40jaiku.com%2Fcomments&entry=stream%2F");
+			g_string_append(string, owner);
+			g_string_append(string, "%40jaiku.com%2Fpresence%2F");
+			s = microfeed_http_url_encode(http, uid);
+			g_string_append(string, s);
+			microfeed_http_free_string(http, s);
+			g_string_append(string, "&content=");
+			s = microfeed_util_string_percent_encoding_escape(text);
+			g_string_append(string, s);
+			free(s);
+	
+			if ((s = microfeed_http_post_data(http, "http://api.jaiku.com/json", &len, string->str))) {
+printf(":%s\n", s);
+				retvalue = TRUE;
+			}			
+			g_string_free(string, TRUE);
 		}
-		http_destroy(http);
+		microfeed_http_free(http);
+		free(owner);
 	}
 	
 	return retvalue;
@@ -208,189 +230,102 @@ gboolean jaiku_send_comment(const gchar* url, const gchar* text) {
 gboolean jaiku_send_jaiku(const gchar* channel, const gchar* text, gint icon_id) {
 	gboolean retvalue = FALSE;
 	gchar* name = NULL;
-	gchar* key = NULL;
-	Http* http;
-	gchar* url;
+	MicrofeedHttp* http;
 	GString* string;
 	GtkWidget* note;
 	gchar* s;
-	gchar* nonce;
-	gchar* location;
+/*	gchar* location; */
 	JsonObject* object;
 	
-	if (http_make_connected() && (http = http_new())) {
-		if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL)) && *name &&
-		    (key = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_KEY, NULL)) && *key) {
-			url = g_strconcat("http://jaiku.com/?user=", name, "&personal_key=", key, NULL);
-			if (get_posting_data(http, url, &nonce, &location)) {
-				string = g_string_new("method=presence.send&user=");
-				g_string_append(string, gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL));
-				g_string_append(string, "&personal_key=");
-				g_string_append(string, gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_KEY, NULL));
-				if (icon_id) {
-					g_string_append(string, "&icon=");
-					g_string_append_printf(string, "%d", icon_id);
-				}
-				g_string_append(string, "&location=");
-				if (location) {
-					s = http_url_encode(http, location);
-					g_string_append(string, s);
-					http_free(http, s);
-				} else {
-					g_string_append(string, "Out%20there%20with%20Mauku");
-				}
-				g_string_append(string, "&message=");
-				if (channel) {
-					g_string_append(string, "#");
-					g_string_append(string, channel);
-					g_string_append(string, "%20");
-				}
-				s = http_url_encode(http, text);
-				g_string_append(string, s);
-				http_free(http, s);
-
-				if ((object = http_post_json_object(http, "http://api.jaiku.com/json", string->str))) {
-					retvalue = TRUE;
-				}			
-
-				g_string_free(string, TRUE);
-				g_free(nonce);
-				g_free(location);
+	if (network_make_connected() && (http = microfeed_http_new())) {
+		initialize_http(http, NULL);
+		if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL)) && *name) {
+			string = g_string_new("method=post&nick=");
+			g_string_append(string, name);
+			if (icon_id) {
+				g_string_append(string, "&icon=");
+				g_string_append_printf(string, "%d", icon_id);
 			}
-			g_free(url);
+/*			g_string_append(string, "&location=");
+			if (location) {
+				s = microfeed_http_url_encode(http, location);
+				g_string_append(string, s);
+				microfeed_http_free_string(http, s);
+			} else {
+				g_string_append(string, "Out%20there%20with%20Mauku");
+			}
+*/			g_string_append(string, "&message=");
+			if (channel) {
+				g_string_append(string, "%23");
+				g_string_append(string, channel);
+				g_string_append(string, "%20");
+			}
+			s = microfeed_util_string_percent_encoding_escape(text);
+			g_string_append(string, s);
+			free(s);
+
+			if ((object = microfeed_http_post_json_object(http, "http://api.jaiku.com/json", string->str))) {
+				retvalue = TRUE;
+			}			
+
+			g_string_free(string, TRUE);
+/*			g_free(location); */
 		}
-		http_destroy(http);
+		microfeed_http_free(http);
 	}
+	g_free(name);
 	
 	return retvalue;
 }
 	
 void jaiku_update_contacts_view(View* view) {
 	gchar* name = NULL;
-	gchar* key = NULL;
 	gchar* url;
 	gchar* credientials;
 	
-	if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL)) && *name &&
-	    (key = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_KEY, NULL)) && *key) {
-		url = g_strdup_printf("http://%s.jaiku.com/json?user=%s&personal_key=%s", name, name, key);
-		backend_start_update(view, url, NULL, &jaiku_item_source, TRUE, update_contacts_view_callback, NULL);
+	if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL)) && *name) {
+		url = g_strdup_printf("http://www.jaiku.com/user/%s/contacts/json", name);
+		backend_start_update(view, url, NULL, &jaiku_item_source, TRUE, update_contacts_view_callback, initialize_http_callback, view_get_window(view));
 		g_free(url);
 	}
 	
 	g_free(name);	
-	g_free(key);
 }
 
 void jaiku_update_explore_view(View* view) {
-	backend_start_update(view, "http://jaiku.com/feed/json", NULL, &jaiku_item_source, FALSE, update_overview_callback, NULL);
+	backend_start_update(view, "http://www.jaiku.com/explore/json", NULL, &jaiku_item_source, FALSE, update_overview_callback, NULL, NULL);
 }
 
 
 void jaiku_update_overview(View* view) {
 	gchar* name = NULL;
-	gchar* key = NULL;
 	gchar* url;
 	
-	if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL)) && *name &&
-	    (key = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_KEY, NULL)) && *key) {
-		url = g_strdup_printf("http://%s.jaiku.com/contacts/feed/json?user=%s&personal_key=%s", name, name, key);
-		backend_start_update(view, url, NULL, &jaiku_item_source, TRUE, update_overview_callback, NULL);
+	if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL)) && *name) {
+		url = g_strdup_printf("http://www.jaiku.com/user/%s/overview/json", name);
+		backend_start_update(view, url, NULL, &jaiku_item_source, TRUE, update_overview_callback, initialize_http_callback, view_get_window(view));
 		g_free(url);
 	}
 	
 	g_free(name);
-	g_free(key);
 }
 void jaiku_update_your_jaikus_view(View* view) {
 	gchar* name = NULL;
-	gchar* key = NULL;
 	gchar* url;
 	
-	if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL)) && *name &&
-	    (key = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_KEY, NULL)) && *key) {
-		url = g_strdup_printf("http://%s.jaiku.com/feed/json?user=%s&personal_key=%s", name, name, key);
-		backend_start_update(view, url, NULL, &jaiku_item_source, TRUE, update_user_view_callback, NULL);
+	if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL)) && *name) {
+		url = g_strdup_printf("http://www.jaiku.com/user/%s/json", name);
+		backend_start_update(view, url, NULL, &jaiku_item_source, TRUE, update_user_view_callback, initialize_http_callback, view_get_window(view));
 		g_free(url);
 	}
 	
 	g_free(name);
-	g_free(key);
 }
 
 static gint compare_item_nicks(gconstpointer a, gconstpointer b) {
 	return strcmp(((ViewItem*)a)->unique_id, ((ViewItem*)b)->unique_id);
 }
 
-static gchar* do_login() {
-	gchar* key = NULL;
-	gchar* name = NULL;
-	gchar* password = NULL;
-	gchar buffer[1024];
-	Http* http;
-	gchar* reply;
-	size_t len;
-
-	if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL)) && *name &&
-	    (password = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_PASSWORD, NULL)) && *password &&
-	    (http = http_new())) {
-		snprintf(buffer, 1024, "%s/.mauku/cookies", (getenv("HOME") ? getenv("HOME") : "/home/user"));
-		http_set_cookie_file(http, buffer);
-		snprintf(buffer, 1024, "redirect_to=http://api.jaiku.com/key&log=%s&pwd=%s", name, password);
-		if ((reply = http_post_data(http, "http://jaiku.com/login?redirect_to=http://api.jaiku.com/key", &len, buffer)) &&
-		    len < 80) {
-			key = g_strndup(reply, len);
-		}
-		http_destroy(http);
-	}
-	g_free(name);
-	g_free(password);
-	
-	return key;
-}
-
-static void* login_thread(void* args) {
-	View* view;
-	gchar* key;
-	GtkWidget* note;
-	
-	view = (View*)args;
-	
-	gdk_threads_enter();
-	note = hildon_note_new_information(NULL, "Please wait!\nLogging into Jaiku...");
-	gtk_widget_show(note);
-	gdk_threads_leave();
-
-	key = do_login();
-
-	gdk_threads_enter();
-	gtk_widget_destroy(note);
-	if (key && *key) {
-		gconf_client_set_string(gconf, MAUKU_GCONF_KEY_JAIKU_KEY, key, NULL);
-
-		/* Hack: Caching is not working properly. */
-		gconf_client_suggest_sync(gconf, NULL);
-		gconf_client_clear_cache(gconf);
-		
-		ui_start_update_overview();
-	} else {
-		gconf_client_set_string(gconf, MAUKU_GCONF_KEY_JAIKU_PASSWORD, "", NULL);
-
-		/* Hack: Caching is not working properly. */
-		gconf_client_suggest_sync(gconf, NULL);
-		gconf_client_clear_cache(gconf);
-
-		note = hildon_note_new_information(NULL, "Login failed.\nPlease, check your name and password.");
-		gtk_dialog_run(GTK_DIALOG(note));
-		gtk_widget_destroy(note);
-		settings_show_dialog();
-	}
-
-	gdk_threads_leave();
-
-	return NULL;
-}
-
 static GString* get_comment_count(JsonObject* comments) {
 	GString* string;
 	gint count;
@@ -402,7 +337,7 @@ static GString* get_comment_count(JsonObject* comments) {
 			return NULL;
 		}
 		s = g_strdup_printf("%d", count);
-	} else if (*(s = json_object_get_string(comments)) != '0') {
+	} else if (*(s = json_object_get_string(comments)) != '0' && *s != 0) {
 		s = g_markup_escape_text(s, -1);
 	} else {
 	
@@ -420,41 +355,7 @@ static GString* get_comment_count(JsonObject* comments) {
 	return string;
 }
 
-static gboolean get_posting_data(Http* http, gchar* url, gchar** nonce, gchar** location) {
-	gchar* page;
-	gchar* start;
-	gchar* end;
-	size_t len;
-	
-	if ((page = http_get_data(http, url, &len)) &&
-	    (page = strstr(page, "<form"))) {
-	    	if ((start = strstr(page, "_nonce")) &&
-		    (start = strstr(start, "value=")) &&
-		    (end = strchr(start + 7, '"')) &&
-		    start != end) {
-			*end = 0;
-			*nonce = g_strdup(start + 7);
-		} else {
-			*nonce = NULL;
-		}
-	    	if ((start = strstr(page, "location")) &&
-		    (start = strstr(start, "value=")) &&
-		    (end = strchr(start + 7, '"')) &&
-		    start != end) {
-			*end = 0;
-			*location = g_strdup(start + 7);
-		} else {
-			*location = NULL;
-		}		
-	} else {
-		
-		return FALSE;
-	}	
-	
-	return TRUE;
-}
-
-static gchar* handle_json_item(JsonObject* json, ViewAddingSession* session, Http* http, gboolean skip_comment, gchar* referred_unique_id, time_t delta) {
+static gchar* handle_json_item(JsonObject* json, ViewAddingSession* session, MicrofeedHttp* http, gboolean skip_comment, gchar* referred_unique_id, time_t delta) {
 	gboolean valid;
 	ViewItem* item;
 	gchar* unique_id;
@@ -464,12 +365,12 @@ static gchar* handle_json_item(JsonObject* json, ViewAddingSession* session, Htt
 	
 	if ((object = json_object_object_get(json, "id"))) {
 		if (referred_unique_id) {
-			unique_id = g_strconcat(jaiku_item_source.name, ":c", json_object_get_string(object), NULL);
+			unique_id = g_strconcat(jaiku_item_source.name, ":C", json_object_get_string(object), NULL);
 		} else {
 			unique_id = g_strconcat(jaiku_item_source.name, ":", json_object_get_string(object), NULL);
 		}
 	} else if ((object = json_object_object_get(json, "comment_id"))) {
-		unique_id = g_strconcat(jaiku_item_source.name, ":c", json_object_get_string(object), NULL);
+		unique_id = g_strconcat(jaiku_item_source.name, ":C", json_object_get_string(object), NULL);
 	} else {
 	
 		return NULL;
@@ -525,9 +426,9 @@ static void on_contact_clicked_callback(View* view, ViewItem* item, gboolean was
 	View* new_view;
 
 	if (*item->unique_id == '#') {
-		url = g_strdup_printf("http://jaiku.com/channel/%s/feed/json", item->unique_id + 1);
+		url = g_strdup_printf("http://www.jaiku.com/channel/%s/json", item->unique_id + 1);
 	} else {
-		url = g_strdup_printf("http://%s.jaiku.com/feed/json", item->unique_id);
+		url = g_strdup_printf("http://www.jaiku.com/user/%s/json", item->unique_id);
 	}
 	new_view = view_new(url, item->unique_id, UI_SENSITIVE_ACTION_ALL & (~UI_SENSITIVE_ACTION_ADD_COMMENT),
 	         update_user_view, NULL);
@@ -553,9 +454,9 @@ static void on_jaiku_clicked_callback(View* view, ViewItem* item, gboolean was_a
 	data = (JaikuData*)item->user_data;
 	if (was_avatar) {
 		if (*data->nick == '#') {
-			url = g_strdup_printf("http://jaiku.com/channel/%s/feed/json", data->nick + 1);
+			url = g_strdup_printf("http://www.jaiku.com/channel/%s/json", data->nick + 1);
 		} else {
-			url = g_strdup_printf("http://%s.jaiku.com/feed/json", data->nick);
+			url = g_strdup_printf("http://www.jaiku.com/user/%s/json", data->nick);
 		}
 		new_view = view_new(url, data->nick, UI_SENSITIVE_ACTION_ALL & (~UI_SENSITIVE_ACTION_ADD_COMMENT),
 		         update_user_view, NULL);
@@ -573,7 +474,7 @@ static void on_channel_menu_item_activate(GtkMenuItem* menu_item, gpointer user_
 	View* view;
 	
 	channel = (gchar*)user_data;
-	url = g_strdup_printf("http://jaiku.com/channel/%s/feed/json", channel);
+	url = g_strdup_printf("http://www.jaiku.com/channel/%s/json", channel);
 	view = view_new(url, channel, UI_SENSITIVE_ACTION_ALL & ~UI_SENSITIVE_ACTION_ADD_COMMENT,
 	         update_user_view, NULL);
 	view_start_update(view, TRUE);
@@ -587,9 +488,9 @@ static void on_jaiku_menu_item_activate(GtkMenuItem* menu_item, gpointer user_da
 
 	nick = (gchar*)user_data;
 	if (*nick == '#') {
-		url = g_strdup_printf("http://jaiku.com/channel/%s/", nick + 1);
+		url = g_strdup_printf("http://www.jaiku.com/channel/%s/", nick + 1);
 	} else {
-		url = g_strdup_printf("http://%s.jaiku.com/", nick);
+		url = g_strdup_printf("http://www.jaiku.com/user/%s/", nick);
 	}
 	osso_rpc_run(osso_context, "com.nokia.osso_browser", "/com/nokia/osso_browser", "com.nokia.osso_browser",
 	             "open_new_window", &retval,  DBUS_TYPE_STRING, url, DBUS_TYPE_INVALID);
@@ -609,7 +510,7 @@ static void on_link_menu_item_activate(GtkMenuItem* menu_item, gpointer user_dat
 	             "open_new_window", &retval,  DBUS_TYPE_STRING, url, DBUS_TYPE_INVALID);
 }
 
-static ViewItem* parse_json_item(JsonObject* json, gchar* unique_id, Http* http, gchar* referred_unique_id, time_t delta) {
+static ViewItem* parse_json_item(JsonObject* json, gchar* unique_id, MicrofeedHttp* http, gchar* referred_unique_id, time_t delta) {
 	ViewItem* item;
 	GString* string;
 	GString* speech;
@@ -624,7 +525,7 @@ static ViewItem* parse_json_item(JsonObject* json, gchar* unique_id, Http* http,
 	string = g_string_new("");
 	speech = g_string_new("");
 
-	if (unique_id[6] == 'c') {
+	if (unique_id[6] == 'C') {
 		item->item_class = &comment_item_class;
 		parse_json_item_comment(json, item, http, string, speech);
 	} else {
@@ -638,7 +539,7 @@ static ViewItem* parse_json_item(JsonObject* json, gchar* unique_id, Http* http,
 	}
 
 	if (!(object = json_object_object_get(json, "created_at")) ||
-	    !(s = strptime(json_object_get_string(object), "%Y-%m-%dT%H:%M:%S GMT", &struct_tm)) || *s) {
+	    !(s = strptime(json_object_get_string(object), "%Y-%m-%dT%H-%M-%SZ", &struct_tm)) || *s) {
 		item->timestamp = time(NULL) - delta;
 	} else {
 		item->timestamp = timegm(&struct_tm) - delta;
@@ -651,7 +552,7 @@ static ViewItem* parse_json_item(JsonObject* json, gchar* unique_id, Http* http,
 	return item;
 }
 
-static void parse_json_item_comment(JsonObject* json, ViewItem* item, Http* http, GString* string, GString* speech) {
+static void parse_json_item_comment(JsonObject* json, ViewItem* item, MicrofeedHttp* http, GString* string, GString* speech) {
 	JsonObject* user;
 	JsonObject* object;
 	gchar* s;
@@ -704,20 +605,27 @@ static void parse_json_item_comment(JsonObject* json, ViewItem* item, Http* http
 			/* gdk_threads_leave(); */
 		}
 	}
-	if ((object = json_object_object_get(json, "title"))) {
-		s = g_markup_escape_text(json_object_get_string(object), -1);
-		g_string_append(string, s);
-		g_free(s);
-	} else {
-		g_string_append(string, "Comment from ");
-		s = g_markup_escape_text(((JaikuData*)item->user_data)->nick, -1);
-		g_string_append(string, s);
+	g_string_append(string, "Comment from ");
+	s = g_markup_escape_text(((JaikuData*)item->user_data)->nick, -1);
+	g_string_append(string, s);
+	g_free(s);
+	if ((object = json_object_object_get(json, "entry_title"))) {
+		s = json_object_get_string(object);
+		g_string_append(string, " on ");
+		if (strlen(s) > 20) {
+			s = g_markup_escape_text(s, 20);
+			g_string_append(string, s);
+			g_string_append(string, "...");
+		} else {
+			s = g_markup_escape_text(s, -1);
+			g_string_append(string, s);
+		}		
 		g_free(s);
 	}
 	if ((object = json_object_object_get(json, "url")) &&
 	    (s = json_object_get_string(object)) &&
-	    !strncmp(s, "http://jaiku.com/channel/", 25)) {
-		s += 25;
+	    !strncmp(s, "http://www.jaiku.com/channel/", 29)) {
+		s += 29;
 		if (!(s2 = strchr(s, '/'))) {
 			s2 = s + strlen(s);
 		}
@@ -747,7 +655,7 @@ static void parse_json_item_comment(JsonObject* json, ViewItem* item, Http* http
 	g_string_append(string, " in Jaiku ");
 }
 
-static void parse_json_item_jaiku(JsonObject* json, ViewItem* item, Http* http, GString* string, GString* speech) {
+static void parse_json_item_jaiku(JsonObject* json, ViewItem* item, MicrofeedHttp* http, GString* string, GString* speech) {
 	JsonObject* user;
 	JsonObject* object;
 	JsonObject* content;
@@ -808,12 +716,12 @@ static void parse_json_item_jaiku(JsonObject* json, ViewItem* item, Http* http,
 	}
 	if ((object = json_object_object_get(json, "url")) &&
 	    (s = json_object_get_string(object))) {
-		if (!strncmp(s, "http://jaiku.com/channel/", 25)) {
+		if (!strncmp(s, "http://www.jaiku.com/channel/", 29)) {
 			if (!(s2 = strchr(s, '#'))) {
 				s2 = s + strlen(s);
 			}
 			item->url = g_strndup(s, s2 - s);
-			s += 25;
+			s += 29;
 			if (!(s2 = strchr(s, '/'))) {
 				s2 = s + strlen(s);
 			}
@@ -828,9 +736,9 @@ static void parse_json_item_jaiku(JsonObject* json, ViewItem* item, Http* http,
 			g_string_append(string, ((JaikuData*)item->user_data)->channel);
 		} else if ((strncmp(s, "http://", 7) || !(s2 = strchr(s + 7, '.')) || strncmp(s2, ".jaiku.com/presence/", 20))) {
 			if (*(((JaikuData*)item->user_data)->nick) == '#') {
-				item->url = g_strdup_printf("http://jaiku.com/channel/%s/presence/%s", ((JaikuData*)item->user_data)->nick + 1, item->unique_id + 6);
+				item->url = g_strdup_printf("http://www.jaiku.com/channel/%s/presence/%s", ((JaikuData*)item->user_data)->nick + 1, item->unique_id + 6);
 			} else {
-				item->url = g_strdup_printf("http://%s.jaiku.com/presence/%s", ((JaikuData*)item->user_data)->nick, item->unique_id + 6);
+				item->url = g_strdup_printf("http://www.jaiku.com/user/%s/presence/%s", ((JaikuData*)item->user_data)->nick, item->unique_id + 6);
 			}
 
 			selection = g_new0(ViewItemSelection, 1);
@@ -878,7 +786,7 @@ static void parse_json_item_jaiku(JsonObject* json, ViewItem* item, Http* http,
 	g_string_append(string, " in Jaiku ");
 }
 
-static gboolean update_contacts_view_callback(ViewAddingSession* session, JsonObject* feed, Http* http, time_t delta, gpointer user_data) {
+static gboolean update_contacts_view_callback(ViewAddingSession* session, JsonObject* feed, MicrofeedHttp* http, time_t delta, gpointer user_data) {
 	JsonObject* contacts;
 	ViewItem* item;
 	GList* list;
@@ -894,6 +802,7 @@ static gboolean update_contacts_view_callback(ViewAddingSession* session, JsonOb
 	gboolean comma;
 	ViewItem* existing;
 	
+	microfeed_http_unset_oauth_authentication(http);
 	if (!(contacts = json_object_object_get(feed, "contacts"))) {
 
 		return FALSE;
@@ -939,8 +848,8 @@ static gboolean update_contacts_view_callback(ViewAddingSession* session, JsonOb
 			key = NULL;
 			if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL)) && *name &&
 			    (key = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_KEY, NULL)) && *key)) {
-				url = g_strdup_printf("http://%s.jaiku.com/presence/json/json?user=%s&personal_key=%s", item->unique_id, name, key);	
-				if ((presence = http_get_json_object(http, real_url))) {
+				url = g_strdup_printf("http://www.jaiku.com/user/%s/presence/json/json?user=%s&personal_key=%s", item->unique_id, name, key);	
+				if ((presence = microfeed_http_get_json_object(http, real_url))) {
 					if ((object = json_object_object_get(presence, "line"))) {
 						s = g_markup_escape_text(json_object_get_string(object), -1);
 						g_string_append(string, s);
@@ -1015,12 +924,14 @@ static gboolean update_contacts_view_callback(ViewAddingSession* session, JsonOb
 	return TRUE;
 }
 
-static gboolean update_overview_callback(ViewAddingSession* session, JsonObject* feed, Http* http, time_t delta, gpointer user_data) {
+static gboolean update_overview_callback(ViewAddingSession* session, JsonObject* feed, MicrofeedHttp* http, time_t delta, gpointer user_data) {
 	JsonObject* stream;
 	JsonObject* json;
 	int i;
 
-	jaiku_update_location(http);
+/*	jaiku_update_location(http); */
+
+	microfeed_http_unset_oauth_authentication(http);
 	if ((stream = json_object_object_get(feed, "stream"))) {		
 		for (i = 0; i < json_object_array_length(stream); i++) {
 			if (!(json = json_object_array_get_idx(stream, i))) {
@@ -1038,26 +949,20 @@ static gboolean update_overview_callback(ViewAddingSession* session, JsonObject*
 }
 
 static void update_thread_view(View* view) {
-	gchar* name = NULL;
-	gchar* key = NULL;
 	gchar* url;
 
-	if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL)) && *name &&
-	    (key = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_KEY, NULL)) && *key) {
-		url = g_strdup_printf("%s/json?user=%s&personal_key=%s", view_get_unique_id(view), name, key);	
-		backend_start_update(view, url, NULL, &jaiku_item_source, FALSE, update_thread_view_callback, NULL);
-		g_free(url);
-	}
-	g_free(name);
-	g_free(key);
+	url = g_strdup_printf("%s/json", view_get_unique_id(view));	
+	backend_start_update(view, url, NULL, &jaiku_item_source, FALSE, update_thread_view_callback, initialize_http_callback, view_get_window(view));
+	g_free(url);
 }
 
-static gboolean update_thread_view_callback(ViewAddingSession* session, JsonObject* feed, Http* http, time_t delta, gpointer user_data) {
+static gboolean update_thread_view_callback(ViewAddingSession* session, JsonObject* feed, MicrofeedHttp* http, time_t delta, gpointer user_data) {
 	gchar* referred_unique_id;
 	JsonObject* stream;
 	JsonObject* json;
 	int i;
 
+	microfeed_http_unset_oauth_authentication(http);
 	if (!(referred_unique_id = handle_json_item(feed, session, http, TRUE, NULL, delta))) {
 		
 		return FALSE;
@@ -1080,25 +985,19 @@ static gboolean update_thread_view_callback(ViewAddingSession* session, JsonObje
 }
 
 static void update_user_view(View* view) {
-	gchar* name = NULL;
-	gchar* key = NULL;
 	gchar* url;
 
-	if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL)) && *name &&
-	    (key = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_KEY, NULL)) && *key) {
-		url = g_strdup_printf("%s?user=%s&personal_key=%s", view_get_unique_id(view), name, key);	
-		backend_start_update(view, url, NULL, &jaiku_item_source, FALSE, update_user_view_callback, NULL);
-		g_free(url);
-	}
-	g_free(name);
-	g_free(key);
+	url = g_strdup(view_get_unique_id(view));	
+	backend_start_update(view, url, NULL, &jaiku_item_source, FALSE, update_user_view_callback, initialize_http_callback, view_get_window(view));
+	g_free(url);
 }
 
-static gboolean update_user_view_callback(ViewAddingSession* session, JsonObject* feed, Http* http, time_t delta, gpointer user_data) {
+static gboolean update_user_view_callback(ViewAddingSession* session, JsonObject* feed, MicrofeedHttp* http, time_t delta, gpointer user_data) {
 	JsonObject* stream;
 	JsonObject* json;
 	int i;
 
+	microfeed_http_unset_oauth_authentication(http);
 	if ((stream = json_object_object_get(feed, "stream"))) {		
 		for (i = 0; i < json_object_array_length(stream); i++) {
 			if (!(json = json_object_array_get_idx(stream, i))) {
