@@ -88,109 +88,109 @@ static void remove_top_bottom_widget(SendingData* sending_data);
 static void update_labels(SendingData* sending_data);
 
 static Icon icons[] = {
-	{ 300, "http://jaiku.com/images/icons/web-speechbubble.gif", NULL },
-	{ 301, "http://jaiku.com/images/icons/web-car.gif", NULL },
-	{ 302, "http://jaiku.com/images/icons/web-alarmclock.gif", NULL },
-	{ 303, "http://jaiku.com/images/icons/web-loudspeaker.gif", NULL },
-	{ 304, "http://jaiku.com/images/icons/web-tram.gif", NULL },
-	{ 305, "http://jaiku.com/images/icons/web-casette.gif", NULL },
-	{ 306, "http://jaiku.com/images/icons/web-underware.gif", NULL },
-	{ 307, "http://jaiku.com/images/icons/web-rollerblade.gif", NULL },
-	{ 308, "http://jaiku.com/images/icons/web-uzi.gif", NULL },
-	{ 309, "http://jaiku.com/images/icons/web-scoop.gif", NULL },
-	{ 310, "http://jaiku.com/images/icons/web-bomb.gif", NULL },
-	{ 311, "http://jaiku.com/images/icons/web-bra.gif", NULL },
-	{ 312, "http://jaiku.com/images/icons/web-videotape.gif", NULL },
-	{ 313, "http://jaiku.com/images/icons/web-cigarettes.gif", NULL },
-	{ 314, "http://jaiku.com/images/icons/web-vinyl.gif", NULL },
-	{ 315, "http://jaiku.com/images/icons/web-champaign.gif", NULL },
-	{ 316, "http://jaiku.com/images/icons/web-airplain.gif", NULL },
-	{ 317, "http://jaiku.com/images/icons/web-bus.gif", NULL },
-	{ 318, "http://jaiku.com/images/icons/web-grumpy.gif", NULL },
-	{ 319, "http://jaiku.com/images/icons/web-coffee.gif", NULL },
-	{ 320, "http://jaiku.com/images/icons/web-camera.gif", NULL },
-	{ 321, "http://jaiku.com/images/icons/web-basketball.gif", NULL },
-	{ 322, "http://jaiku.com/images/icons/web-beer.gif", NULL },
-	{ 323, "http://jaiku.com/images/icons/web-binoculars.gif", NULL },
-	{ 324, "http://jaiku.com/images/icons/web-boiler.gif", NULL },
-	{ 325, "http://jaiku.com/images/icons/web-walk.gif", NULL },
-	{ 326, "http://jaiku.com/images/icons/web-wallclock.gif", NULL },
-	{ 327, "http://jaiku.com/images/icons/web-trashcan.gif", NULL },
-	{ 328, "http://jaiku.com/images/icons/web-tv.gif", NULL },
-	{ 329, "http://jaiku.com/images/icons/web-computing.gif", NULL },
-	{ 330, "http://jaiku.com/images/icons/web-videocamera.gif", NULL },
-	{ 331, "http://jaiku.com/images/icons/web-game.gif", NULL },
-	{ 332, "http://jaiku.com/images/icons/web-cone.gif", NULL },
-	{ 333, "http://jaiku.com/images/icons/web-driller.gif", NULL },
-	{ 334, "http://jaiku.com/images/icons/web-popcorn.gif", NULL },
-	{ 335, "http://jaiku.com/images/icons/web-playshirt.gif", NULL },
-	{ 336, "http://jaiku.com/images/icons/web-disc.gif", NULL },
-	{ 337, "http://jaiku.com/images/icons/web-event.gif", NULL },
-	{ 338, "http://jaiku.com/images/icons/web-exclamationmark.gif", NULL },
-	{ 339, "http://jaiku.com/images/icons/web-football.gif", NULL },
-/*	{ 340, "http://jaiku.com/images/icons/web-footballshoe.gif", NULL }, */
-	{ 341, "http://jaiku.com/images/icons/web-eat.gif", NULL },
-	{ 342, "http://jaiku.com/images/icons/web-gameboy.gif", NULL },
-	{ 343, "http://jaiku.com/images/icons/web-grenade.gif", NULL },
-	{ 344, "http://jaiku.com/images/icons/web-hand.gif", NULL },
-	{ 345, "http://jaiku.com/images/icons/web-hanger.gif", NULL },
-	{ 346, "http://jaiku.com/images/icons/web-hearingprotector.gif", NULL },
-	{ 347, "http://jaiku.com/images/icons/web-love.gif", NULL },
-	{ 348, "http://jaiku.com/images/icons/web-balloons.gif", NULL },
-	{ 349, "http://jaiku.com/images/icons/web-clock.gif", NULL },
-	{ 350, "http://jaiku.com/images/icons/web-barrier.gif", NULL },
-/*	{ 351, "http://jaiku.com/images/icons/web-laptop.gif", NULL }, */
-	{ 352, "http://jaiku.com/images/icons/web-megaphone.gif", NULL },
-	{ 353, "http://jaiku.com/images/icons/web-microwave.gif", NULL },
-	{ 354, "http://jaiku.com/images/icons/web-book.gif", NULL },
-	{ 355, "http://jaiku.com/images/icons/web-middlefinger.gif", NULL },
-	{ 356, "http://jaiku.com/images/icons/web-notes.gif", NULL },
-	{ 357, "http://jaiku.com/images/icons/web-question.gif", NULL },
-	{ 358, "http://jaiku.com/images/icons/web-rollator.gif", NULL },
-	{ 359, "http://jaiku.com/images/icons/web-shuttlecock.gif", NULL },
-	{ 360, "http://jaiku.com/images/icons/web-salt.gif", NULL },
-	{ 361, "http://jaiku.com/images/icons/web-scull.gif", NULL },
-	{ 362, "http://jaiku.com/images/icons/web-sk8.gif", NULL },
-	{ 363, "http://jaiku.com/images/icons/web-sleep.gif", NULL },
-	{ 364, "http://jaiku.com/images/icons/web-snorkeling.gif", NULL },
-	{ 365, "http://jaiku.com/images/icons/web-snowflake.gif", NULL },
-	{ 366, "http://jaiku.com/images/icons/web-soda.gif", NULL },
-	{ 367, "http://jaiku.com/images/icons/web-song.gif", NULL },
-	{ 368, "http://jaiku.com/images/icons/web-spraycan.gif", NULL },
-	{ 369, "http://jaiku.com/images/icons/web-sticks.gif", NULL },
-	{ 370, "http://jaiku.com/images/icons/web-storm.gif", NULL },
-	{ 371, "http://jaiku.com/images/icons/web-straitjacket.gif", NULL },
-	{ 372, "http://jaiku.com/images/icons/web-metro.gif", NULL },
-	{ 373, "http://jaiku.com/images/icons/web-luggage.gif", NULL },
-	{ 374, "http://jaiku.com/images/icons/web-sun.gif", NULL },
-	{ 375, "http://jaiku.com/images/icons/web-taxi.gif", NULL },
-	{ 376, "http://jaiku.com/images/icons/web-technics.gif", NULL },
-	{ 377, "http://jaiku.com/images/icons/web-toaster.gif", NULL },
-	{ 378, "http://jaiku.com/images/icons/web-train.gif", NULL },
-	{ 379, "http://jaiku.com/images/icons/web-wheelchair.gif", NULL },
-	{ 380, "http://jaiku.com/images/icons/web-zippo.gif", NULL },
-	{ 381, "http://jaiku.com/images/icons/web-icecream.gif", NULL },
-	{ 382, "http://jaiku.com/images/icons/web-movie.gif", NULL },
-	{ 383, "http://jaiku.com/images/icons/web-makeup.gif", NULL },
-	{ 384, "http://jaiku.com/images/icons/web-bandaid.gif", NULL },
-	{ 385, "http://jaiku.com/images/icons/web-wine.gif", NULL },
-	{ 386, "http://jaiku.com/images/icons/web-clean.gif", NULL },
-	{ 387, "http://jaiku.com/images/icons/web-blading.gif", NULL },
-	{ 388, "http://jaiku.com/images/icons/web-bike.gif", NULL },
-	{ 389, "http://jaiku.com/images/icons/web-pils.gif", NULL },
-	{ 390, "http://jaiku.com/images/icons/web-picnic.gif", NULL },
-	{ 391, "http://jaiku.com/images/icons/web-lifejacket.gif", NULL },
-	{ 392, "http://jaiku.com/images/icons/web-home.gif", NULL },
-	{ 393, "http://jaiku.com/images/icons/web-happy.gif", NULL },
-	{ 394, "http://jaiku.com/images/icons/web-toiletpaper.gif", NULL },
-	{ 395, "http://jaiku.com/images/icons/web-theatre.gif", NULL },
-	{ 396, "http://jaiku.com/images/icons/web-shop.gif", NULL },
-	{ 397, "http://jaiku.com/images/icons/web-search.gif", NULL },
-	{ 398, "http://jaiku.com/images/icons/web-cloudy.gif", NULL },
-	{ 399, "http://jaiku.com/images/icons/web-hurry.gif", NULL },
-	{ 400, "http://jaiku.com/images/icons/web-morning.gif", NULL },
-/*	{ 401, "http://jaiku.com/images/icons/web-car.gif", NULL }, */
-	{ 402, "http://jaiku.com/images/icons/web-baby-boy.gif", NULL },
+	{ 300, "http://www.jaiku.com/themes/classic/icons/web-speechbubble.gif", NULL },
+	{ 301, "http://www.jaiku.com/themes/classic/icons/web-car.gif", NULL },
+	{ 302, "http://www.jaiku.com/themes/classic/icons/web-alarmclock.gif", NULL },
+	{ 303, "http://www.jaiku.com/themes/classic/icons/web-loudspeaker.gif", NULL },
+	{ 304, "http://www.jaiku.com/themes/classic/icons/web-tram.gif", NULL },
+	{ 305, "http://www.jaiku.com/themes/classic/icons/web-casette.gif", NULL },
+	{ 306, "http://www.jaiku.com/themes/classic/icons/web-underware.gif", NULL },
+	{ 307, "http://www.jaiku.com/themes/classic/icons/web-rollerblade.gif", NULL },
+	{ 308, "http://www.jaiku.com/themes/classic/icons/web-uzi.gif", NULL },
+	{ 309, "http://www.jaiku.com/themes/classic/icons/web-scoop.gif", NULL },
+	{ 310, "http://www.jaiku.com/themes/classic/icons/web-bomb.gif", NULL },
+	{ 311, "http://www.jaiku.com/themes/classic/icons/web-bra.gif", NULL },
+	{ 312, "http://www.jaiku.com/themes/classic/icons/web-videotape.gif", NULL },
+	{ 313, "http://www.jaiku.com/themes/classic/icons/web-cigarettes.gif", NULL },
+	{ 314, "http://www.jaiku.com/themes/classic/icons/web-vinyl.gif", NULL },
+	{ 315, "http://www.jaiku.com/themes/classic/icons/web-champaign.gif", NULL },
+	{ 316, "http://www.jaiku.com/themes/classic/icons/web-airplain.gif", NULL },
+	{ 317, "http://www.jaiku.com/themes/classic/icons/web-bus.gif", NULL },
+	{ 318, "http://www.jaiku.com/themes/classic/icons/web-grumpy.gif", NULL },
+	{ 319, "http://www.jaiku.com/themes/classic/icons/web-coffee.gif", NULL },
+	{ 320, "http://www.jaiku.com/themes/classic/icons/web-camera.gif", NULL },
+	{ 321, "http://www.jaiku.com/themes/classic/icons/web-basketball.gif", NULL },
+	{ 322, "http://www.jaiku.com/themes/classic/icons/web-beer.gif", NULL },
+	{ 323, "http://www.jaiku.com/themes/classic/icons/web-binoculars.gif", NULL },
+	{ 324, "http://www.jaiku.com/themes/classic/icons/web-boiler.gif", NULL },
+	{ 325, "http://www.jaiku.com/themes/classic/icons/web-walk.gif", NULL },
+	{ 326, "http://www.jaiku.com/themes/classic/icons/web-wallclock.gif", NULL },
+	{ 327, "http://www.jaiku.com/themes/classic/icons/web-trashcan.gif", NULL },
+	{ 328, "http://www.jaiku.com/themes/classic/icons/web-tv.gif", NULL },
+	{ 329, "http://www.jaiku.com/themes/classic/icons/web-computing.gif", NULL },
+	{ 330, "http://www.jaiku.com/themes/classic/icons/web-videocamera.gif", NULL },
+	{ 331, "http://www.jaiku.com/themes/classic/icons/web-game.gif", NULL },
+	{ 332, "http://www.jaiku.com/themes/classic/icons/web-cone.gif", NULL },
+	{ 333, "http://www.jaiku.com/themes/classic/icons/web-driller.gif", NULL },
+	{ 334, "http://www.jaiku.com/themes/classic/icons/web-popcorn.gif", NULL },
+	{ 335, "http://www.jaiku.com/themes/classic/icons/web-playshirt.gif", NULL },
+	{ 336, "http://www.jaiku.com/themes/classic/icons/web-disc.gif", NULL },
+	{ 337, "http://www.jaiku.com/themes/classic/icons/web-event.gif", NULL },
+	{ 338, "http://www.jaiku.com/themes/classic/icons/web-exclamationmark.gif", NULL },
+	{ 339, "http://www.jaiku.com/themes/classic/icons/web-football.gif", NULL },
+/*	{ 340, "http://www.jaiku.com/themes/classic/icons/web-footballshoe.gif", NULL }, */
+	{ 341, "http://www.jaiku.com/themes/classic/icons/web-eat.gif", NULL },
+	{ 342, "http://www.jaiku.com/themes/classic/icons/web-gameboy.gif", NULL },
+	{ 343, "http://www.jaiku.com/themes/classic/icons/web-grenade.gif", NULL },
+	{ 344, "http://www.jaiku.com/themes/classic/icons/web-hand.gif", NULL },
+	{ 345, "http://www.jaiku.com/themes/classic/icons/web-hanger.gif", NULL },
+	{ 346, "http://www.jaiku.com/themes/classic/icons/web-hearingprotector.gif", NULL },
+	{ 347, "http://www.jaiku.com/themes/classic/icons/web-love.gif", NULL },
+	{ 348, "http://www.jaiku.com/themes/classic/icons/web-balloons.gif", NULL },
+	{ 349, "http://www.jaiku.com/themes/classic/icons/web-clock.gif", NULL },
+	{ 350, "http://www.jaiku.com/themes/classic/icons/web-barrier.gif", NULL },
+/*	{ 351, "http://www.jaiku.com/themes/classic/icons/web-laptop.gif", NULL }, */
+	{ 352, "http://www.jaiku.com/themes/classic/icons/web-megaphone.gif", NULL },
+	{ 353, "http://www.jaiku.com/themes/classic/icons/web-microwave.gif", NULL },
+	{ 354, "http://www.jaiku.com/themes/classic/icons/web-book.gif", NULL },
+	{ 355, "http://www.jaiku.com/themes/classic/icons/web-middlefinger.gif", NULL },
+	{ 356, "http://www.jaiku.com/themes/classic/icons/web-notes.gif", NULL },
+	{ 357, "http://www.jaiku.com/themes/classic/icons/web-question.gif", NULL },
+	{ 358, "http://www.jaiku.com/themes/classic/icons/web-rollator.gif", NULL },
+	{ 359, "http://www.jaiku.com/themes/classic/icons/web-shuttlecock.gif", NULL },
+	{ 360, "http://www.jaiku.com/themes/classic/icons/web-salt.gif", NULL },
+	{ 361, "http://www.jaiku.com/themes/classic/icons/web-scull.gif", NULL },
+	{ 362, "http://www.jaiku.com/themes/classic/icons/web-sk8.gif", NULL },
+	{ 363, "http://www.jaiku.com/themes/classic/icons/web-sleep.gif", NULL },
+	{ 364, "http://www.jaiku.com/themes/classic/icons/web-snorkeling.gif", NULL },
+	{ 365, "http://www.jaiku.com/themes/classic/icons/web-snowflake.gif", NULL },
+	{ 366, "http://www.jaiku.com/themes/classic/icons/web-soda.gif", NULL },
+	{ 367, "http://www.jaiku.com/themes/classic/icons/web-song.gif", NULL },
+	{ 368, "http://www.jaiku.com/themes/classic/icons/web-spraycan.gif", NULL },
+	{ 369, "http://www.jaiku.com/themes/classic/icons/web-sticks.gif", NULL },
+	{ 370, "http://www.jaiku.com/themes/classic/icons/web-storm.gif", NULL },
+	{ 371, "http://www.jaiku.com/themes/classic/icons/web-straitjacket.gif", NULL },
+	{ 372, "http://www.jaiku.com/themes/classic/icons/web-metro.gif", NULL },
+	{ 373, "http://www.jaiku.com/themes/classic/icons/web-luggage.gif", NULL },
+	{ 374, "http://www.jaiku.com/themes/classic/icons/web-sun.gif", NULL },
+	{ 375, "http://www.jaiku.com/themes/classic/icons/web-taxi.gif", NULL },
+	{ 376, "http://www.jaiku.com/themes/classic/icons/web-technics.gif", NULL },
+	{ 377, "http://www.jaiku.com/themes/classic/icons/web-toaster.gif", NULL },
+	{ 378, "http://www.jaiku.com/themes/classic/icons/web-train.gif", NULL },
+	{ 379, "http://www.jaiku.com/themes/classic/icons/web-wheelchair.gif", NULL },
+	{ 380, "http://www.jaiku.com/themes/classic/icons/web-zippo.gif", NULL },
+	{ 381, "http://www.jaiku.com/themes/classic/icons/web-icecream.gif", NULL },
+	{ 382, "http://www.jaiku.com/themes/classic/icons/web-movie.gif", NULL },
+	{ 383, "http://www.jaiku.com/themes/classic/icons/web-makeup.gif", NULL },
+	{ 384, "http://www.jaiku.com/themes/classic/icons/web-bandaid.gif", NULL },
+	{ 385, "http://www.jaiku.com/themes/classic/icons/web-wine.gif", NULL },
+	{ 386, "http://www.jaiku.com/themes/classic/icons/web-clean.gif", NULL },
+	{ 387, "http://www.jaiku.com/themes/classic/icons/web-blading.gif", NULL },
+	{ 388, "http://www.jaiku.com/themes/classic/icons/web-bike.gif", NULL },
+	{ 389, "http://www.jaiku.com/themes/classic/icons/web-pils.gif", NULL },
+	{ 390, "http://www.jaiku.com/themes/classic/icons/web-picnic.gif", NULL },
+	{ 391, "http://www.jaiku.com/themes/classic/icons/web-lifejacket.gif", NULL },
+	{ 392, "http://www.jaiku.com/themes/classic/icons/web-home.gif", NULL },
+	{ 393, "http://www.jaiku.com/themes/classic/icons/web-happy.gif", NULL },
+	{ 394, "http://www.jaiku.com/themes/classic/icons/web-toiletpaper.gif", NULL },
+	{ 395, "http://www.jaiku.com/themes/classic/icons/web-theatre.gif", NULL },
+	{ 396, "http://www.jaiku.com/themes/classic/icons/web-shop.gif", NULL },
+	{ 397, "http://www.jaiku.com/themes/classic/icons/web-search.gif", NULL },
+	{ 398, "http://www.jaiku.com/themes/classic/icons/web-cloudy.gif", NULL },
+	{ 399, "http://www.jaiku.com/themes/classic/icons/web-hurry.gif", NULL },
+	{ 400, "http://www.jaiku.com/themes/classic/icons/web-morning.gif", NULL },
+/*	{ 401, "http://www.jaiku.com/themes/classic/icons/web-car.gif", NULL }, */
+	{ 402, "http://www.jaiku.com/themes/classic/icons/web-baby-boy.gif", NULL },
 	
 	{ 0, NULL, NULL }
 };
@@ -364,7 +364,7 @@ void destroy_sending_data(SendingData* sending_data) {
 static void on_add_icon_clicked(GtkButton* not_used, SendingData* sending_data) {
 	GtkWidget* dialog;
 	GtkWidget* table;
-	Http* http;
+	MicrofeedHttp* http;
 	GtkWidget* image;
 	GtkWidget* event_box;
 	int i;
@@ -373,7 +373,7 @@ static void on_add_icon_clicked(GtkButton* not_used, SendingData* sending_data)
 	GArray* icon_data_array;
 	IconData icon_data;
 
-	if (!http_make_connected() || !(http = http_new())) {
+	if (!network_make_connected() || !(http = microfeed_http_new())) {
 		return;
 	}
 	dialog = gtk_dialog_new_with_buttons("Select an icon for a Jaiku", NULL, GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -415,7 +415,7 @@ static void on_add_icon_clicked(GtkButton* not_used, SendingData* sending_data)
 		miaouw_scrolled_window_activate_scrolling(MIAOUW_SCROLLED_WINDOW(scrolled_window), event_box);
 	}
 	gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrolled_window), table);
-	http_destroy(http);
+	microfeed_http_free(http);
 
 	id = 0;
 	gtk_widget_show_all(dialog);
@@ -505,7 +505,7 @@ static void on_send_ok_clicked(SendingData* sending_data) {
 	GtkTextIter end_iter;
 	GString* string;
 	const gchar* text;
-	Http* http;
+	MicrofeedHttp* http;
 	GtkWidget* note;
 	gchar* s;
 	gchar buffer[1024];
