@@ -46,7 +46,6 @@
 typedef struct {
 	GtkWidget* jaiku_enabled_check_button;
 	GtkWidget* jaiku_name_entry;
-	GtkWidget* jaiku_password_entry; /* Must be after name_entry */
 	GtkWidget* twitter_enabled_check_button;
 	GtkWidget* twitter_name_entry;
 	GtkWidget* twitter_password_entry; /* Must be after name_entry */
@@ -75,14 +74,13 @@ GConfClient* gconf = NULL;
 
 void settings_init() {
 	GConfValue* value;
-	gchar* s;
 	gint version;
 	
 	gconf = gconf_client_get_default();
 	gconf_client_add_dir(gconf, MAUKU_GCONF_DIR, GCONF_CLIENT_PRELOAD_RECURSIVE, NULL);
 
-	if ((version = gconf_client_get_int(gconf, MAUKU_GCONF_KEY_CONFIGURATION_VERSION, NULL)) < 3) {
-		gconf_client_set_int(gconf, MAUKU_GCONF_KEY_CONFIGURATION_VERSION, 3, NULL);
+	if ((version = gconf_client_get_int(gconf, MAUKU_GCONF_KEY_CONFIGURATION_VERSION, NULL)) < 4) {
+		gconf_client_set_int(gconf, MAUKU_GCONF_KEY_CONFIGURATION_VERSION, 4, NULL);
 		if (version < 1) {
 			gconf_client_set_bool(gconf, MAUKU_GCONF_KEY_SHOW_SCROLLBAR, FALSE, NULL);
 		}
@@ -109,23 +107,19 @@ void settings_init() {
 			}
 		}
 		if (version < 3) {
-			if ((value = gconf_client_get(gconf, MAUKU_GCONF_DIR "/key", NULL))) {
-				gconf_client_set(gconf, MAUKU_GCONF_KEY_JAIKU_KEY, value, NULL);
-				gconf_value_free(value);
-				gconf_client_unset(gconf, MAUKU_GCONF_DIR "/key", NULL);
-			}
+			gconf_client_unset(gconf, MAUKU_GCONF_DIR "/key", NULL);
 			if ((value = gconf_client_get(gconf, MAUKU_GCONF_DIR "/name", NULL))) {
 				gconf_client_set(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, value, NULL);
 				gconf_value_free(value);
 				gconf_client_unset(gconf, MAUKU_GCONF_DIR "/name", NULL);
 			}
-			if ((value = gconf_client_get(gconf, MAUKU_GCONF_DIR "/password", NULL))) {
-				gconf_client_set(gconf, MAUKU_GCONF_KEY_JAIKU_PASSWORD, value, NULL);
-				gconf_value_free(value);
-				gconf_client_unset(gconf, MAUKU_GCONF_DIR "/password", NULL);
-			}
+			gconf_client_unset(gconf, MAUKU_GCONF_DIR "/password", NULL);
 			gconf_client_set_bool(gconf, MAUKU_GCONF_KEY_JAIKU_ENABLED, TRUE, NULL);
 		}
+		if (version < 4) {
+			gconf_client_unset(gconf, MAUKU_GCONF_DIR "/jaiku/key", NULL);
+			gconf_client_unset(gconf, MAUKU_GCONF_DIR "/jaiku/password", NULL);
+		}		
 	}
 
 	if (!(value = gconf_client_get(gconf, MAUKU_GCONF_KEY_UPDATE, NULL))) {
@@ -148,8 +142,13 @@ void settings_init() {
 	} else {
 		gconf_value_free(value);
 	}
-	if (!(value = gconf_client_get(gconf, MAUKU_GCONF_KEY_JAIKU_PASSWORD, NULL))) {
-		gconf_client_set_string(gconf, MAUKU_GCONF_KEY_JAIKU_PASSWORD, "", NULL);
+	if (!(value = gconf_client_get(gconf, MAUKU_GCONF_KEY_JAIKU_ACCESS_TOKEN, NULL))) {
+		gconf_client_set_string(gconf, MAUKU_GCONF_KEY_JAIKU_ACCESS_TOKEN, "", NULL);
+	} else {
+		gconf_value_free(value);
+	}
+	if (!(value = gconf_client_get(gconf, MAUKU_GCONF_KEY_JAIKU_ACCESS_TOKEN_SECRET, NULL))) {
+		gconf_client_set_string(gconf, MAUKU_GCONF_KEY_JAIKU_ACCESS_TOKEN_SECRET, "", NULL);
 	} else {
 		gconf_value_free(value);
 	}
@@ -208,11 +207,6 @@ void settings_init() {
 	} else {
 		gconf_value_free(value);
 	}
-	if (!(s = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL)) || !*s ||
-	    !(s = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_PASSWORD, NULL)) || !*s) {
-		gconf_client_set_string(gconf, MAUKU_GCONF_KEY_JAIKU_KEY, "", NULL);
-	}
-	g_free(s);
 	
 	/* Hack: Caching is not working properly. */
 	gconf_client_suggest_sync(gconf, NULL);
@@ -251,16 +245,16 @@ void settings_show_dialog() {
 	}
 	settings_dialog_active = TRUE;
 	
-	data = (SettingsDialogData*)g_malloc(sizeof(SettingsDialogData));
+	data = (SettingsDialogData*)g_malloc0(sizeof(SettingsDialogData));
 
 	dialog = gtk_dialog_new_with_buttons("Settings", NULL, GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT,
 	                                     GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
 	notebook = gtk_notebook_new();
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), notebook, TRUE, TRUE, 0);
 
-	append_login_tab_to_notebook(GTK_NOTEBOOK(notebook), "Jaiku", "http://m.jaiku.com/join",
-	                             MAUKU_GCONF_KEY_JAIKU_NAME, MAUKU_GCONF_KEY_JAIKU_PASSWORD, MAUKU_GCONF_KEY_JAIKU_ENABLED,
-				     &data->jaiku_name_entry, &data->jaiku_password_entry, &data->jaiku_enabled_check_button,
+	append_login_tab_to_notebook(GTK_NOTEBOOK(notebook), "Jaiku", "http://www.jaiku.com/join",
+	                             MAUKU_GCONF_KEY_JAIKU_NAME, NULL, MAUKU_GCONF_KEY_JAIKU_ENABLED,
+				     &data->jaiku_name_entry, NULL, &data->jaiku_enabled_check_button,
 				     &jaiku_handler_id);
 	append_login_tab_to_notebook(GTK_NOTEBOOK(notebook), "Twitter", "https://twitter.com/signup",
 	                             MAUKU_GCONF_KEY_TWITTER_NAME, MAUKU_GCONF_KEY_TWITTER_PASSWORD, MAUKU_GCONF_KEY_TWITTER_ENABLED,
@@ -370,24 +364,26 @@ static void append_login_tab_to_notebook(GtkNotebook* notebook, gchar* tab_title
 	}	
 	gtk_container_add(GTK_CONTAINER(hbox), *name_entry_pointer);
 
-	hbox = gtk_hbox_new(TRUE, 4);
-	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 4);
-	label = gtk_label_new("Password:");
-	gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
-	gtk_container_add(GTK_CONTAINER(hbox), label);
-	*password_entry_pointer = gtk_entry_new();
-#if HILDON == 1
-	hildon_gtk_entry_set_input_mode(GTK_ENTRY(*password_entry_pointer), HILDON_GTK_INPUT_MODE_FULL | HILDON_GTK_INPUT_MODE_INVISIBLE);
-#else
-	g_object_set(G_OBJECT(*password_entry_pointer), "autocap", FALSE, NULL);
-#endif
-	gtk_entry_set_visibility(GTK_ENTRY(*password_entry_pointer), FALSE);
-	if ((s =  gconf_client_get_string(gconf, password_gconf_key, NULL))) {
-		gtk_entry_set_text(GTK_ENTRY(*password_entry_pointer), s);
-		g_free(s);
+	if (password_entry_pointer) {
+		hbox = gtk_hbox_new(TRUE, 4);
+		gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 4);
+		label = gtk_label_new("Password:");
+		gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
+		gtk_container_add(GTK_CONTAINER(hbox), label);
+		*password_entry_pointer = gtk_entry_new();
+	#if HILDON == 1
+		hildon_gtk_entry_set_input_mode(GTK_ENTRY(*password_entry_pointer), HILDON_GTK_INPUT_MODE_FULL | HILDON_GTK_INPUT_MODE_INVISIBLE);
+	#else
+		g_object_set(G_OBJECT(*password_entry_pointer), "autocap", FALSE, NULL);
+	#endif
+		gtk_entry_set_visibility(GTK_ENTRY(*password_entry_pointer), FALSE);
+		if ((s =  gconf_client_get_string(gconf, password_gconf_key, NULL))) {
+			gtk_entry_set_text(GTK_ENTRY(*password_entry_pointer), s);
+			g_free(s);
+		}
+		*handler_id_pointer = g_signal_connect(*password_entry_pointer, "focus-in-event", G_CALLBACK(on_focus_in_event), handler_id_pointer);
+		gtk_container_add(GTK_CONTAINER(hbox), *password_entry_pointer);
 	}
-	*handler_id_pointer = g_signal_connect(*password_entry_pointer, "focus-in-event", G_CALLBACK(on_focus_in_event), handler_id_pointer);
-	gtk_container_add(GTK_CONTAINER(hbox), *password_entry_pointer);
 	
 	s = g_strdup_printf("Join %s (opens in a browser)", tab_title);
 	button = gtk_button_new_with_label(s);
@@ -411,8 +407,12 @@ static void on_blink_led_notify(GConfClient* client, guint cnxn_id, GConfEntry *
 static void on_enabled_toggled(GtkToggleButton* toggle_button, gpointer user_data) {
 	GtkWidget** widgets = (GtkWidget**)user_data;
 	
-	gtk_widget_set_sensitive(widgets[0], gtk_toggle_button_get_active(toggle_button));
-	gtk_widget_set_sensitive(widgets[1], gtk_toggle_button_get_active(toggle_button));
+	if (widgets[0]) {
+		gtk_widget_set_sensitive(widgets[0], gtk_toggle_button_get_active(toggle_button));
+	}
+	if (widgets[1]) {
+		gtk_widget_set_sensitive(widgets[1], gtk_toggle_button_get_active(toggle_button));
+	}
 }
 
 static gboolean on_focus_in_event(GtkEntry* entry, GdkEventFocus* event, gulong* handler_id) {
@@ -436,7 +436,6 @@ static void on_response(GtkDialog* dialog, gint response, SettingsDialogData* da
 	const gchar* text;
 	gint integer;
 	gchar* s;
-	gboolean clear_key = FALSE;
 	gboolean update_overview = FALSE;
 
 	if (response != GTK_RESPONSE_REJECT) {
@@ -445,21 +444,11 @@ static void on_response(GtkDialog* dialog, gint response, SettingsDialogData* da
 		text = gtk_entry_get_text(GTK_ENTRY(data->jaiku_name_entry));
 		if (!(s = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, NULL)) || strcmp(text, s)) {
 			gconf_client_set_string(gconf, MAUKU_GCONF_KEY_JAIKU_NAME, text, NULL);
-			clear_key = TRUE;
+			gconf_client_set_string(gconf, MAUKU_GCONF_KEY_JAIKU_ACCESS_TOKEN, "", NULL);
+			gconf_client_set_string(gconf, MAUKU_GCONF_KEY_JAIKU_ACCESS_TOKEN_SECRET, "", NULL);
 		}
 		g_free(s);
 
-		text = gtk_entry_get_text(GTK_ENTRY(data->jaiku_password_entry));
-		if (!(s = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_JAIKU_PASSWORD, NULL)) || strcmp(text, s)) {
-			gconf_client_set_string(gconf, MAUKU_GCONF_KEY_JAIKU_PASSWORD, text, NULL);
-			clear_key = TRUE;
-		}
-		g_free(s);
-		
-		if (clear_key) {
-			gconf_client_set_string(gconf, MAUKU_GCONF_KEY_JAIKU_KEY, "", NULL);
-			jaiku_start_login();
-		}
 
 		gconf_client_set_bool(gconf, MAUKU_GCONF_KEY_TWITTER_ENABLED, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->twitter_enabled_check_button)), NULL);
 		
